@@ -16,7 +16,7 @@ use DynaLoader();
 use Carp ();
 @ISA = qw(DynaLoader);
 
-$VERSION = '2.01_14';
+$VERSION = '2.01_16';
 
 bootstrap DBD::mSQL $VERSION;
 
@@ -294,13 +294,18 @@ Interface (DBI)
 
     use DBI;
 
-    $dbh = DBI->connect("DBI:mSQL:$database:$hostname:$port",
-			undef, undef);
+    $driver = "mSQL"; # or "mSQL1";
+    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
+
+    $dbh = DBI->connect($dsn,	undef, undef);
 
         or
 
-    $dbh = DBI->connect("DBI:mysql:$database:$hostname:$port",
-			$user, $password);
+    $driver = "mysql";
+    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
+
+    $dbh = DBI->connect($dsn, $user, $password);
+
 
     @databases = DBD::mysql::dr->func($host, $port, '_ListDBs');
     @tables = $dbh->func( '_ListTables' );
@@ -354,9 +359,10 @@ of the I<Msql-Mysql-modules> package.
 
     use DBI;
 
-    $dsn = "DBI:mSQL:$database";
-    $dsn = "DBI:mSQL:database=$database;host=$hostname";
-    $dsn = "DBI:mSQL:database=$database;host=$hostname;port=$port";
+    $driver = "mSQL";  #  or "mSQL1"
+    $dsn = "DBI:$driver:$database";
+    $dsn = "DBI:$driver:database=$database;host=$hostname";
+    $dsn = "DBI:$driver:database=$database;host=$hostname;port=$port";
 
     $dbh = DBI->connect($dsn, undef, undef);
 
