@@ -16,7 +16,7 @@ use vars qw($QUIET @ISA @EXPORT @EXPORT_OK $VERSION $db_errstr);
 $db_errstr = '';
 $QUIET  = 0;
 @ISA    = qw(DBI); # Inherits Exporter and DynaLoader via DBI
-$VERSION = '1.19_14';
+$VERSION = '1.19_16';
 
 # @EXPORT is a relict from old times...
 @EXPORT = qw(
@@ -119,7 +119,7 @@ sub quote ($$) { my($self) = shift; $self->{'dbh'}->quote(@_); }
 sub errmsg ($) {
     my($self) = shift;
     if (!ref($self)) {
-	$db_errstr;
+	$DBI::errstr || $db_errstr;
     } elsif ($self->{'dbh'}) {
 	$self->{'dbh'}->errstr();
     } else {
@@ -226,8 +226,8 @@ sub AUTOLOAD {
 	}
     }
 
-  Carp::croak "$AUTOLOAD: Not defined in $class and not"
-      . " autoloadable (last try $meth)";
+  Carp::croak("$AUTOLOAD: Not defined in $class and not"
+	      . " autoloadable (last try $meth)");
 }
 
 
@@ -258,8 +258,7 @@ Msql / Mysql - Perl interfaces to the mSQL and mysql databases
 =head1 SYNOPSIS
 
   use Msql;
-	
-  $dbh = Msql->connect;
+
   $dbh = Msql->connect($host);
   $dbh = Msql->connect($host, $database);
 
@@ -270,6 +269,12 @@ Msql / Mysql - Perl interfaces to the mSQL and mysql databases
   $dbh = Mysql->connect(undef, $database, $user, $password);
   $dbh = Mysql->connect($host, $database, $user, $password);
 
+      or
+
+  $dbh = Msql1->connect($host);
+  $dbh = Msql1->connect($host, $database);
+
+
   $dbh->selectdb($database);
 	
   @arr = $dbh->listdbs;
@@ -325,16 +330,20 @@ it through a statement handle returned by a query or a listfields
 statement. The only class you name explicitly is Msql or Mysql. They
 offer you the connect command:
 
-  $dbh = Msql->connect;
   $dbh = Msql->connect($host);
   $dbh = Msql->connect($host, $database);
 
     or
 
-  $dbh = Mysql->connect(undef, undef, $user, $password);
   $dbh = Mysql->connect($host, undef, $user, $password);
   $dbh = Mysql->connect($host, $database, $user, $password);
 
+    or
+
+  $dbh = Msql1->connect($host);
+  $dbh = Msql1->connect($host, $database);
+
+
 This connects you with the desired host/database. With no argument or
 with an empty string as the first argument it connects to the UNIX
 socket, which has a much better performance than
@@ -416,22 +425,21 @@ close the connection, choose to do one of the following:
 
 Both drivers, Msql and Mysql implement a method -E<gt>errmsg(), which
 returns a textual error message. Mysql additionally supports a method
--E<gt>errno returning the corresponding error number. Note that Msql's
-I<errmsg> is a static method, thus it is legal to fetch
+-E<gt>errno returning the corresponding error number.
 
-    Msql->errmsg();
+Usually you do fetch error messages with
 
-Mysql doesn't support this, fetching the error message is only valid
-via
+    $errmsg = $dbh->errmsg();
 
-    $dbh->errmsg();
+In situations where a $dbh is not available (for example when
+connect() failed) you may instead do a
+
+    $errmsg = Msql->errmsg();
+        or
+    $errmsg = Mysql->errmsg();
+        or
+    $errmsg = Msql1->errmsg();
 
-I recommend, that even Msql users restrict themselves to the latter
-for portability reasons. There are also global variables $Msql::db_errstr
-and $Mysql::db_errstr, which always hold the last error message. The former
-is reset with the next executed command, the latter not. Usually
-there's no need for accessing the global variables, with one exception:
-If the I<connect> method fails, you need them.
 
 =head2 The C<-w> switch
 
@@ -479,14 +487,7 @@ Now lets reconsider the above methods with regard to metadata.
 
 =head2 Database Handle
 
-As said above you get a database handle with
-
-  $dbh = Msql->connect($host, $database);
-
-    or
-
-  $dbh = Mysql->connect($host, $database);
-
+As said above you get a database handle with the connect() method.
 The database handle knows about the socket, the host, and the database
 it is connected to.
 
